import * as i0 from '@angular/core';
import { InjectionToken, inject, ElementRef, Injectable, Directive, Attribute } from '@angular/core';
import { Observable } from 'rxjs';
import { WINDOW } from '@ng-web-apis/common';

const SafeObserver = typeof ResizeObserver !== 'undefined'
    ? ResizeObserver
    : class {
        observe() { }
        unobserve() { }
        disconnect() { }
    };

const RESIZE_OPTION_BOX_DEFAULT = 'content-box';
const RESIZE_OPTION_BOX = new InjectionToken('[RESIZE_OPTION_BOX]: Box model to observe changes', {
    providedIn: 'root',
    factory: () => RESIZE_OPTION_BOX_DEFAULT,
});

class ResizeObserverService extends Observable {
    constructor() {
        const nativeElement = inject(ElementRef).nativeElement;
        const box = inject(RESIZE_OPTION_BOX);
        super(subscriber => {
            const observer = new SafeObserver(entries => subscriber.next(entries));
            observer.observe(nativeElement, { box });
            return () => {
                observer.disconnect();
            };
        });
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: ResizeObserverService, deps: [], target: i0.ɵɵFactoryTarget.Injectable });
    static ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: ResizeObserverService });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: ResizeObserverService, decorators: [{
            type: Injectable
        }], ctorParameters: function () { return []; } });

class WaResizeObserver {
    box;
    waResizeObserver = inject(ResizeObserverService);
    constructor(
    // eslint-disable-next-line @angular-eslint/no-attribute-decorator
    box) {
        this.box = box;
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: WaResizeObserver, deps: [{ token: 'waResizeBox', attribute: true }], target: i0.ɵɵFactoryTarget.Directive });
    static ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "16.2.12", type: WaResizeObserver, isStandalone: true, selector: "[waResizeObserver]", outputs: { waResizeObserver: "waResizeObserver" }, providers: [
            ResizeObserverService,
            {
                provide: RESIZE_OPTION_BOX,
                deps: [ElementRef],
                useFactory: ({ nativeElement, }) => {
                    const attribute = nativeElement.getAttribute('waResizeBox');
                    return attribute || RESIZE_OPTION_BOX_DEFAULT;
                },
            },
        ], ngImport: i0 });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: WaResizeObserver, decorators: [{
            type: Directive,
            args: [{
                    standalone: true,
                    selector: '[waResizeObserver]',
                    outputs: ['waResizeObserver'],
                    providers: [
                        ResizeObserverService,
                        {
                            provide: RESIZE_OPTION_BOX,
                            deps: [ElementRef],
                            useFactory: ({ nativeElement, }) => {
                                const attribute = nativeElement.getAttribute('waResizeBox');
                                return attribute || RESIZE_OPTION_BOX_DEFAULT;
                            },
                        },
                    ],
                }]
        }], ctorParameters: function () { return [{ type: undefined, decorators: [{
                    type: Attribute,
                    args: ['waResizeBox']
                }] }]; } });
/**
 * @deprecated: use {@link WaResizeObserver}
 */
const ResizeObserverDirective = WaResizeObserver;

const RESIZE_OBSERVER_SUPPORT = new InjectionToken('[RESIZE_OBSERVER_SUPPORT]: Resize Observer API support', {
    providedIn: 'root',
    factory: () => !!inject(WINDOW).ResizeObserver,
});

/**
 * Generated bundle index. Do not edit.
 */

export { RESIZE_OBSERVER_SUPPORT, RESIZE_OPTION_BOX, RESIZE_OPTION_BOX_DEFAULT, ResizeObserverDirective, ResizeObserverService, WaResizeObserver };
//# sourceMappingURL=ng-web-apis-resize-observer.mjs.map
